﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Text;
using System.Windows.Forms;
using System.Drawing.Drawing2D;

namespace PlayJoySharp {
	public partial class JoystickPositionPreview : UserControl {

		public JoystickPositionPreview() {
			SetStyle(ControlStyles.AllPaintingInWmPaint | ControlStyles.UserPaint | ControlStyles.ResizeRedraw | ControlStyles.OptimizedDoubleBuffer, true);
			InitializeComponent();
		}

		private float x = 0f;
		private float y = 0f;
		private bool pressed = false;

		public float X {
			get { return this.x; }
			set { this.x = value; this.Invalidate(); }
		}
		

		public float Y {
			get { return this.y; }
			set { this.y = value; this.Invalidate(); }
		}

		public bool Pressed {
			get { return this.pressed; }
			set { this.pressed = value; this.Invalidate(); }
		}

		protected override void OnPaint(PaintEventArgs e) {

			e.Graphics.SmoothingMode = System.Drawing.Drawing2D.SmoothingMode.HighQuality;
	
			RectangleF TotalAreaRectangle = new RectangleF(0f, 0f, this.Width - 1f, this.Height - 1f);

			using (SolidBrush BackgroundBrush = new SolidBrush(Color.FromKnownColor(this.Enabled && this.pressed ? KnownColor.Highlight : KnownColor.Control))) {
				using (Pen LinesPen = new Pen(Color.FromKnownColor(this.Enabled ? (this.pressed ? KnownColor.HighlightText : KnownColor.ControlText) : KnownColor.ControlDark), 1f)) {
					using (Pen OuterPen = new Pen(Color.FromKnownColor(this.Enabled ? KnownColor.ControlText : KnownColor.ControlDark), 1f)) {


						e.Graphics.FillEllipse(BackgroundBrush, TotalAreaRectangle);

						float ClampX = Math.Max(-1f, Math.Min(+1f, x));
						float ClampY = Math.Max(-1f, Math.Min(+1f, y));

						if (Math.Abs(x) > 0.01f) {
							e.Graphics.DrawArc(LinesPen, (TotalAreaRectangle.Width * (0.5f - Math.Abs(ClampX) / 2f)), TotalAreaRectangle.Y, TotalAreaRectangle.Width * Math.Abs(ClampX), TotalAreaRectangle.Height, ClampX > 0f ? 270f : 90f, 180f);
						} else {
							e.Graphics.DrawLine(LinesPen, TotalAreaRectangle.Width / 2f, 0f, TotalAreaRectangle.Width / 2f, TotalAreaRectangle.Height);
						}

						if (Math.Abs(y) > 0.01f) {
							e.Graphics.DrawArc(LinesPen, TotalAreaRectangle.X, (TotalAreaRectangle.Height * (0.5f - Math.Abs(ClampY) / 2f)), TotalAreaRectangle.Width, TotalAreaRectangle.Height * Math.Abs(ClampY), ClampY > 0f ? 0f : 180f, 180f);
						} else {
							e.Graphics.DrawLine(LinesPen, 0f, TotalAreaRectangle.Height / 2f, TotalAreaRectangle.Width, TotalAreaRectangle.Height / 2f);
						}

						e.Graphics.DrawEllipse(OuterPen, TotalAreaRectangle);
					}
					
				}
			}
			base.OnPaint(e);
		}


	}
}
